==> korolev-monix_3-1.5.0-M1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"monix","t":"monix","d":"","k":"static"},
{"l":"korolev/monix.html","n":"korolev.monix","t":"package korolev.monix","d":"korolev/monix","k":"package"},
{"l":"korolev/monix.html","n":"monixTaskEffect","t":"def monixTaskEffect(implicit scheduler: Scheduler): Effect[Task]","d":"korolev/monix","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"MonixTaskEffect","t":"class MonixTaskEffect(implicit scheduler: Scheduler) extends Effect[Task]","d":"korolev/monix/MonixTaskEffect","k":"class"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"delay","t":"def delay[A](value: => A): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"fail","t":"def fail[A](e: Throwable): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"flatMap","t":"def flatMap[A, B](m: Task[A])(f: A => Task[B]): Task[B]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"fork","t":"def fork[A](m: => Task[A])(implicit ec: ExecutionContext): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"fromTry","t":"def fromTry[A](value: => Try[A]): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"map","t":"def map[A, B](m: Task[A])(f: A => B): Task[B]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"never","t":"def never[T]: Task[T]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"promise","t":"def promise[A](cb: Either[Throwable, A] => Unit => Unit): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"promiseF","t":"def promiseF[A](cb: Either[Throwable, A] => Unit => Task[Unit]): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"pure","t":"def pure[A](value: A): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"recover","t":"def recover[A, AA >: A](m: Task[A])(f: PartialFunction[Throwable, AA]): Task[AA]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"recoverF","t":"def recoverF[A, AA >: A](m: Task[A])(f: PartialFunction[Throwable, Task[AA]]): Task[AA]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"run","t":"def run[A](m: Task[A]): Either[Throwable, A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"runAsync","t":"def runAsync[A](m: Task[A])(callback: Either[Throwable, A] => Unit): Unit","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"sequence","t":"def sequence[A](in: List[Task[A]]): Task[List[A]]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"start","t":"def start[A](m: => Task[A])(implicit ec: ExecutionContext): Task[Fiber[Task, A]]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"toFuture","t":"def toFuture[A](m: Task[A]): Future[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"unit","t":"def unit: Task[Unit]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"docs/index.html","n":"monix","t":"monix","d":"","k":"static"}];

==> korolev-monix_3-1.6.0-M1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"monix","t":"monix","d":"","k":"static"},
{"l":"korolev/monix.html","n":"korolev.monix","t":"package korolev.monix","d":"korolev/monix","k":"package"},
{"l":"korolev/monix.html","n":"monixTaskEffect","t":"def monixTaskEffect(implicit scheduler: Scheduler): Effect[Task]","d":"korolev/monix","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"MonixTaskEffect","t":"class MonixTaskEffect(implicit scheduler: Scheduler) extends Effect[Task]","d":"korolev/monix/MonixTaskEffect","k":"class"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"blocking","t":"def blocking[A](f: => A)(implicit ec: ExecutionContext): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"delay","t":"def delay[A](value: => A): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"fail","t":"def fail[A](e: Throwable): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"flatMap","t":"def flatMap[A, B](m: Task[A])(f: A => Task[B]): Task[B]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"fork","t":"def fork[A](m: => Task[A])(implicit ec: ExecutionContext): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"fromTry","t":"def fromTry[A](value: => Try[A]): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"map","t":"def map[A, B](m: Task[A])(f: A => B): Task[B]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"never","t":"def never[T]: Task[T]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"promise","t":"def promise[A](cb: Either[Throwable, A] => Unit => Unit): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"promiseF","t":"def promiseF[A](cb: Either[Throwable, A] => Unit => Task[Unit]): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"pure","t":"def pure[A](value: A): Task[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"recover","t":"def recover[A, AA >: A](m: Task[A])(f: PartialFunction[Throwable, AA]): Task[AA]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"recoverF","t":"def recoverF[A, AA >: A](m: Task[A])(f: PartialFunction[Throwable, Task[AA]]): Task[AA]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"run","t":"def run[A](m: Task[A]): Either[Throwable, A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"runAsync","t":"def runAsync[A](m: Task[A])(callback: Either[Throwable, A] => Unit): Unit","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"sequence","t":"def sequence[A](in: List[Task[A]]): Task[List[A]]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"start","t":"def start[A](m: => Task[A])(implicit ec: ExecutionContext): Task[Fiber[Task, A]]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"toFuture","t":"def toFuture[A](m: Task[A]): Future[A]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"korolev/monix/MonixTaskEffect.html","n":"unit","t":"def unit: Task[Unit]","d":"korolev/monix/MonixTaskEffect","k":"def"},
{"l":"docs/index.html","n":"monix","t":"monix","d":"","k":"static"}];
